/****************************************************************************
** Meta object code from reading C++ file 'personsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kpeople-5.43.0/src/personsmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'personsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KPeople__PersonsModel_t {
    QByteArrayData data[16];
    char stringdata0[176];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KPeople__PersonsModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KPeople__PersonsModel_t qt_meta_stringdata_KPeople__PersonsModel = {
    {
QT_MOC_LITERAL(0, 0, 21), // "KPeople::PersonsModel"
QT_MOC_LITERAL(1, 22, 16), // "modelInitialized"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 7), // "success"
QT_MOC_LITERAL(4, 48, 3), // "get"
QT_MOC_LITERAL(5, 52, 3), // "row"
QT_MOC_LITERAL(6, 56, 4), // "role"
QT_MOC_LITERAL(7, 61, 13), // "isInitialized"
QT_MOC_LITERAL(8, 75, 4), // "Role"
QT_MOC_LITERAL(9, 80, 17), // "FormattedNameRole"
QT_MOC_LITERAL(10, 98, 9), // "PhotoRole"
QT_MOC_LITERAL(11, 108, 13), // "PersonUriRole"
QT_MOC_LITERAL(12, 122, 15), // "PersonVCardRole"
QT_MOC_LITERAL(13, 138, 17), // "ContactsVCardRole"
QT_MOC_LITERAL(14, 156, 10), // "GroupsRole"
QT_MOC_LITERAL(15, 167, 8) // "UserRole"

    },
    "KPeople::PersonsModel\0modelInitialized\0"
    "\0success\0get\0row\0role\0isInitialized\0"
    "Role\0FormattedNameRole\0PhotoRole\0"
    "PersonUriRole\0PersonVCardRole\0"
    "ContactsVCardRole\0GroupsRole\0UserRole"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KPeople__PersonsModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       1,   32, // properties
       1,   36, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
       4,    2,   27,    2, 0x42 /* Public | isScriptable */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,

 // methods: parameters
    QMetaType::QVariant, QMetaType::Int, QMetaType::Int,    5,    6,

 // properties: name, type, flags
       7, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       0,

 // enums: name, flags, count, data
       8, 0x0,    7,   40,

 // enum data: key, value
       9, uint(KPeople::PersonsModel::FormattedNameRole),
      10, uint(KPeople::PersonsModel::PhotoRole),
      11, uint(KPeople::PersonsModel::PersonUriRole),
      12, uint(KPeople::PersonsModel::PersonVCardRole),
      13, uint(KPeople::PersonsModel::ContactsVCardRole),
      14, uint(KPeople::PersonsModel::GroupsRole),
      15, uint(KPeople::PersonsModel::UserRole),

       0        // eod
};

void KPeople::PersonsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PersonsModel *_t = static_cast<PersonsModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->modelInitialized((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: { QVariant _r = _t->get((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (PersonsModel::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PersonsModel::modelInitialized)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        PersonsModel *_t = static_cast<PersonsModel *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isInitialized(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KPeople::PersonsModel::staticMetaObject = {
    { &QAbstractItemModel::staticMetaObject, qt_meta_stringdata_KPeople__PersonsModel.data,
      qt_meta_data_KPeople__PersonsModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KPeople::PersonsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPeople::PersonsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KPeople__PersonsModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int KPeople::PersonsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KPeople::PersonsModel::modelInitialized(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
